pub type SharedView = Rc<RefCell<StreamView>>;Expand description
A StreamView addressable from both the desktop and the event pump.
Aliased Type
pub struct SharedView { /* private fields */ }pub type SharedView = Rc<RefCell<StreamView>>;A StreamView addressable from both the desktop and the event pump.
pub struct SharedView { /* private fields */ }